Module stack

Module stack 

Structs

Iter
An iterator over the nodes of an RcuStack.
IterRef
An iterator over popped nodes of an RcuStack.

Type Aliases

Ref
An RCU reference to a element removed from an RcuQueue.
RefOwned
An owned RCU reference to a element removed from an RcuQueue.