RcuStack

Struct RcuStack 

pub struct RcuStack<T>
where T: Send,
{ /* private fields */ }
A concurrent stack make out of linked nodes which are protected by RCU.

Implementations

Source

impl<T> RcuStack<T>
where T: Send,

pub fn new(_rcu: &Rcu) -> Self

Initialize an empty stack.

pub fn push(&self, rscs: &RcuRSCS, val: T)

Push a new value onto the stack.

Source

impl<T> RcuStack<T>
where T: Send + Sync,

pub fn pop(&self, rscs: &RcuRSCS) -> RcuBox<RcuNode<T>>

Pop the top node off the stack.

Full ownership of the inner value can be recovered after a grace period by calling node.into_inner().into_inner() to unwrap both the RcuBox and the RcuNode layers.

pub fn iter<'a>(&'a self, rscs: &'a RcuRSCS) -> impl Iterator<Item = &'a T> + 'a

Iterate through all values held in nodes reachable from the top node.