RcuList

Struct RcuList 

pub struct RcuList<T, F = RcuDefaultFlavor> { /* private fields */ }
Defines a RCU doubly linked list.

This linked list supports multiple concurrents readers at any time, but only a single writer at a time. The list uses an internal lock for writing operations.

Limitations

Mutable References

Because there might always be readers borrowing a node’s data, it is impossible to get a mutable references to the data inside the linked list. You should design the type stored in the list with interior mutabillity that can be shared between threads.

List Length

Because a writer might concurrently modify the list, the amount of node might change at any moment. To prevent user error (e.g. allocate an array for each node), there is no .len() method.

Safety

It is safe to send an Arc<RcuList<T>> to a non-registered RCU thread. A non-registered thread may drop an RcuList<T> without calling any RCU primitives since lifetime rules prevent any other thread from accessing a RCU reference.

Implementations

Source

impl<T, F> RcuList<T, F>
where F: RcuFlavor,

pub fn new() -> Arc<Self>

Creates a new RCU linked list.

pub fn contains<G>(&self, x: &T, guard: &G) -> bool
where T: PartialEq, G: RcuGuard<Flavor = F>,

Returns true if the list contains an element equal to the given value.

pub fn push_back(&self, data: T) -> Result<()>

Adds an element to the back of a list.

Note

This operation may block.

pub fn push_front(&self, data: T) -> Result<()>

Adds an element to the front of a list.

Note

This operation may block.

pub fn pop_back(&self) -> Result<Option<Ref<T, F>>>
where T: Send,

Removes an element from the back of a list.

Note

This operation may block.

pub fn pop_front(&self) -> Result<Option<Ref<T, F>>>
where T: Send,

Removes an element from the fron of a list.

Note

This operation may block.

pub fn is_empty(&self) -> bool

Returns true if the list is empty.

Note
  • This operation computes linearly in O(1) time.
pub fn back<'me, 'guard, G>(&'me self, guard: &'guard G) -> Option<&'guard T>
where G: RcuGuard<Flavor = F>, 'me: 'guard,

Provides a reference to the back element, or None if the list is empty.

pub fn front<'me, 'guard, G>(&'me self, guard: &'guard G) -> Option<&'guard T>
where G: RcuGuard<Flavor = F>, 'me: 'guard,

Provides a reference to the front element, or None if the list is empty.

pub fn iter_forward<'me, 'guard, G>( &'me self, guard: &'guard G, ) -> Iter<'guard, T, G, true>
where G: RcuGuard<Flavor = F>, 'me: 'guard,

Returns an iterator over the list.

The iterator yields all items from back to front.

pub fn iter_reverse<'me, 'guard, G>( &'me self, guard: &'guard G, ) -> Iter<'guard, T, G, false>
where G: RcuGuard, 'me: 'guard,

Returns an iterator over the list.

The iterator yields all items from front to back.